package
Version:
v0.0.0-...-f3b78e2
Opens a new window with list of versions in this module.
Published: Nov 27, 2018
License: GPL-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func (r *Client) Call(serviceMethod string, args interface{}, reply interface{}) error
Source Files
¶
Click to show internal directories.
Click to hide internal directories.